CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
59 lines
1.5 KiB
C++
59 lines
1.5 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
HIP_TEST_CASE(Unit_hipStreamPerThread_EventRecord) {
|
|
hipEvent_t event;
|
|
HIP_CHECK(hipEventCreate(&event));
|
|
HIP_CHECK(hipEventRecord(event, hipStreamPerThread));
|
|
HIP_CHECK(hipEventSynchronize(event));
|
|
HIP_CHECK(hipEventDestroy(event));
|
|
}
|
|
|
|
__global__ void update_even_odd(unsigned int N, int* out) {
|
|
for (unsigned int i = 0; i < N; ++i) {
|
|
if (i % 2 == 0) {
|
|
out[i] = 2;
|
|
} else {
|
|
out[i] = 3;
|
|
}
|
|
}
|
|
}
|
|
HIP_TEST_CASE(Unit_hipStreamPerThread_EventSynchronize) {
|
|
int* A_h = nullptr;
|
|
int* A_d = nullptr;
|
|
unsigned int size = 1000;
|
|
|
|
HIP_CHECK(hipHostMalloc(&A_h, size * sizeof(int)));
|
|
HIP_CHECK(hipMalloc(&A_d, size * sizeof(int)));
|
|
|
|
hipEvent_t start, end;
|
|
HIP_CHECK(hipEventCreate(&start));
|
|
HIP_CHECK(hipEventCreate(&end));
|
|
|
|
HIP_CHECK(hipEventRecord(start, hipStreamPerThread));
|
|
update_even_odd<<<1, 1>>>(size, A_d);
|
|
HIP_CHECK(hipEventRecord(end, hipStreamPerThread));
|
|
|
|
HIP_CHECK(hipEventSynchronize(end));
|
|
HIP_CHECK(hipMemcpy(A_h, A_d, size * sizeof(int), hipMemcpyDeviceToHost));
|
|
|
|
// Verify result
|
|
for (unsigned int i = 0; i < size; ++i) {
|
|
if (i % 2 == 0 && A_h[i] != 2)
|
|
REQUIRE(false);
|
|
else if (i % 2 != 0 && A_h[i] != 3) {
|
|
REQUIRE(false);
|
|
}
|
|
}
|
|
|
|
HIP_CHECK(hipHostFree(A_h));
|
|
HIP_CHECK(hipFree(A_d));
|
|
HIP_CHECK(hipEventDestroy(start));
|
|
HIP_CHECK(hipEventDestroy(end));
|
|
}
|